@@ -27,13 +27,13 @@ from sqlalchemy.sql.elements import conv
 from . import batch
 from . import schemaobj
 from .. import util
+from ..ddl.base import _ServerDefaultType
 from ..util import sqla_compat
 from ..util.compat import formatannotation_fwdref
 from ..util.compat import inspect_formatargspec
 from ..util.compat import inspect_getfullargspec
 from ..util.sqla_compat import _literal_bindparam
 
-
 if TYPE_CHECKING:
     from typing import Literal
 
@@ -44,8 +44,6 @@ if TYPE_CHECKING:
     from sqlalchemy.sql.expression import TableClause
     from sqlalchemy.sql.expression import TextClause
     from sqlalchemy.sql.schema import Column
-    from sqlalchemy.sql.schema import Computed
-    from sqlalchemy.sql.schema import Identity
     from sqlalchemy.sql.schema import SchemaItem
     from sqlalchemy.types import TypeEngine
 
@@ -632,6 +630,7 @@ class Operations(AbstractOperations):
             *,
             schema: Optional[str] = None,
             if_not_exists: Optional[bool] = None,
+            inline_references: Optional[bool] = None,
         ) -> None:
             """Issue an "add column" instruction using the current
             migration context.
@@ -650,21 +649,16 @@ class Operations(AbstractOperations):
 
             .. note::
 
-                With the exception of NOT NULL constraints or single-column FOREIGN
-                KEY constraints, other kinds of constraints such as PRIMARY KEY,
-                UNIQUE or CHECK constraints **cannot** be generated using this
-                method; for these constraints, refer to operations such as
-                :meth:`.Operations.create_primary_key` and
-                :meth:`.Operations.create_check_constraint`. In particular, the
-                following :class:`~sqlalchemy.schema.Column` parameters are
-                **ignored**:
+                Not all contraint types may be indicated with this directive.
+                PRIMARY KEY, NOT NULL, FOREIGN KEY, and CHECK are honored, UNIQUE
+                is currently not.
+
+                .. versionadded:: 1.18.2 Added support for PRIMARY KEY to be
+                   emitted within :meth:`.Operations.add_column`.
+
+                As of 1.18.2, the following :class:`~sqlalchemy.schema.Column`
+                parameters are **ignored**:
 
-                * :paramref:`~sqlalchemy.schema.Column.primary_key` - SQL databases
-                  typically do not support an ALTER operation that can add
-                  individual columns one at a time to an existing primary key
-                  constraint, therefore it's less ambiguous to use the
-                  :meth:`.Operations.create_primary_key` method, which assumes no
-                  existing primary key constraint is present.
                 * :paramref:`~sqlalchemy.schema.Column.unique` - use the
                   :meth:`.Operations.create_unique_constraint` method
                 * :paramref:`~sqlalchemy.schema.Column.index` - use the
@@ -673,9 +667,9 @@ class Operations(AbstractOperations):
 
             The provided :class:`~sqlalchemy.schema.Column` object may include a
             :class:`~sqlalchemy.schema.ForeignKey` constraint directive,
-            referencing a remote table name. For this specific type of constraint,
-            Alembic will automatically emit a second ALTER statement in order to
-            add the single-column FOREIGN KEY constraint separately::
+            referencing a remote table name. By default, Alembic will automatically
+            emit a second ALTER statement in order to add the single-column FOREIGN
+            KEY constraint separately::
 
                 from alembic import op
                 from sqlalchemy import Column, INTEGER, ForeignKey
@@ -685,6 +679,20 @@ class Operations(AbstractOperations):
                     Column("account_id", INTEGER, ForeignKey("accounts.id")),
                 )
 
+            To render the FOREIGN KEY constraint inline within the ADD COLUMN
+            directive, use the ``inline_references`` parameter. This can improve
+            performance on large tables since the constraint is marked as valid
+            immediately for nullable columns::
+
+                from alembic import op
+                from sqlalchemy import Column, INTEGER, ForeignKey
+
+                op.add_column(
+                    "organization",
+                    Column("account_id", INTEGER, ForeignKey("accounts.id")),
+                    inline_references=True,
+                )
+
             The column argument passed to :meth:`.Operations.add_column` is a
             :class:`~sqlalchemy.schema.Column` construct, used in the same way it's
             used in SQLAlchemy. In particular, values or functions to be indicated
@@ -713,6 +721,14 @@ class Operations(AbstractOperations):
 
              .. versionadded:: 1.16.0
 
+            :param inline_references: If True, renders FOREIGN KEY constraints
+             inline within the ADD COLUMN directive using REFERENCES syntax,
+             rather than as a separate ALTER TABLE ADD CONSTRAINT statement.
+             This is supported by PostgreSQL, Oracle, MySQL 5.7+, and
+             MariaDB 10.5+.
+
+             .. versionadded:: 1.18.2
+
             """  # noqa: E501
             ...
 
@@ -724,7 +740,7 @@ class Operations(AbstractOperations):
             nullable: Optional[bool] = None,
             comment: Union[str, Literal[False], None] = False,
             server_default: Union[
-                str, bool, Identity, Computed, TextClause, None
+                _ServerDefaultType, None, Literal[False]
             ] = False,
             new_column_name: Optional[str] = None,
             type_: Union[TypeEngine[Any], Type[TypeEngine[Any]], None] = None,
@@ -732,7 +748,7 @@ class Operations(AbstractOperations):
                 TypeEngine[Any], Type[TypeEngine[Any]], None
             ] = None,
             existing_server_default: Union[
-                str, bool, Identity, Computed, TextClause, None
+                _ServerDefaultType, None, Literal[False]
             ] = False,
             existing_nullable: Optional[bool] = None,
             existing_comment: Optional[str] = None,
@@ -1674,6 +1690,7 @@ class BatchOperations(AbstractOperations):
             insert_before: Optional[str] = None,
             insert_after: Optional[str] = None,
             if_not_exists: Optional[bool] = None,
+            inline_references: Optional[bool] = None,
         ) -> None:
             """Issue an "add column" instruction using the current
             batch migration context.
@@ -1691,14 +1708,16 @@ class BatchOperations(AbstractOperations):
             *,
             nullable: Optional[bool] = None,
             comment: Union[str, Literal[False], None] = False,
-            server_default: Any = False,
+            server_default: Union[
+                _ServerDefaultType, None, Literal[False]
+            ] = False,
             new_column_name: Optional[str] = None,
             type_: Union[TypeEngine[Any], Type[TypeEngine[Any]], None] = None,
             existing_type: Union[
                 TypeEngine[Any], Type[TypeEngine[Any]], None
             ] = None,
             existing_server_default: Union[
-                str, bool, Identity, Computed, None
+                _ServerDefaultType, None, Literal[False]
             ] = False,
             existing_nullable: Optional[bool] = None,
             existing_comment: Optional[str] = None,
