@@ -935,7 +935,11 @@ class BatchAPITest(TestBase):
 
         assert (
             mock.call.add_column(
-                "tname", column, schema=None, if_not_exists=None
+                "tname",
+                column,
+                schema=None,
+                if_not_exists=None,
+                inline_references=None,
             )
             in batch.impl.operations.impl.mock_calls
         )
@@ -2291,7 +2295,6 @@ class BatchRoundTripMySQLTest(BatchRoundTripTest):
     def _datetime_server_default_fixture(self):
         return func.current_timestamp()
 
-    @exclusions.fails()
     def test_drop_pk_col_readd_pk_col(self):
         super().test_drop_pk_col_readd_pk_col()
 
@@ -2348,7 +2351,6 @@ class BatchRoundTripPostgresqlTest(BatchRoundTripTest):
     def _datetime_server_default_fixture(self):
         return func.current_timestamp()
 
-    @exclusions.fails()
     def test_drop_pk_col_readd_pk_col(self):
         super().test_drop_pk_col_readd_pk_col()
 
